==> kubernetes-model-networking-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/NetworkPolicyPeerFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class NetworkPolicyPeerFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent<A>{
  public NetworkPolicyPeerFluentImpl() {
  }
  public NetworkPolicyPeerFluentImpl(io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeer instance) {
    this.withIpBlock(instance.getIpBlock()); 
    this.withNamespaceSelector(instance.getNamespaceSelector()); 
    this.withPodSelector(instance.getPodSelector()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.networking.v1.IPBlockBuilder ipBlock;
  private io.fabric8.kubernetes.api.model.LabelSelectorBuilder namespaceSelector;
  private io.fabric8.kubernetes.api.model.LabelSelectorBuilder podSelector;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildIpBlock instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.networking.v1.IPBlock getIpBlock() {
    return this.ipBlock!=null?this.ipBlock.build():null;
  }
  public io.fabric8.kubernetes.api.model.networking.v1.IPBlock buildIpBlock() {
    return this.ipBlock!=null?this.ipBlock.build():null;
  }
  public A withIpBlock(io.fabric8.kubernetes.api.model.networking.v1.IPBlock ipBlock) {
    _visitables.get("ipBlock").remove(this.ipBlock);
    if (ipBlock!=null){ this.ipBlock= new io.fabric8.kubernetes.api.model.networking.v1.IPBlockBuilder(ipBlock); _visitables.get("ipBlock").add(this.ipBlock);} return (A) this;
  }
  public java.lang.Boolean hasIpBlock() {
    return this.ipBlock != null;
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.IpBlockNested<A> withNewIpBlock() {
    return new io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluentImpl.IpBlockNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.IpBlockNested<A> withNewIpBlockLike(io.fabric8.kubernetes.api.model.networking.v1.IPBlock item) {
    return new io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluentImpl.IpBlockNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.IpBlockNested<A> editIpBlock() {
    return withNewIpBlockLike(getIpBlock());
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.IpBlockNested<A> editOrNewIpBlock() {
    return withNewIpBlockLike(getIpBlock() != null ? getIpBlock(): new io.fabric8.kubernetes.api.model.networking.v1.IPBlockBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.IpBlockNested<A> editOrNewIpBlockLike(io.fabric8.kubernetes.api.model.networking.v1.IPBlock item) {
    return withNewIpBlockLike(getIpBlock() != null ? getIpBlock(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildNamespaceSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getNamespaceSelector() {
    return this.namespaceSelector!=null?this.namespaceSelector.build():null;
  }
  public io.fabric8.kubernetes.api.model.LabelSelector buildNamespaceSelector() {
    return this.namespaceSelector!=null?this.namespaceSelector.build():null;
  }
  public A withNamespaceSelector(io.fabric8.kubernetes.api.model.LabelSelector namespaceSelector) {
    _visitables.get("namespaceSelector").remove(this.namespaceSelector);
    if (namespaceSelector!=null){ this.namespaceSelector= new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(namespaceSelector); _visitables.get("namespaceSelector").add(this.namespaceSelector);} return (A) this;
  }
  public java.lang.Boolean hasNamespaceSelector() {
    return this.namespaceSelector != null;
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.NamespaceSelectorNested<A> withNewNamespaceSelector() {
    return new io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluentImpl.NamespaceSelectorNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return new io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluentImpl.NamespaceSelectorNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.NamespaceSelectorNested<A> editNamespaceSelector() {
    return withNewNamespaceSelectorLike(getNamespaceSelector());
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector() {
    return withNewNamespaceSelectorLike(getNamespaceSelector() != null ? getNamespaceSelector(): new io.fabric8.kubernetes.api.model.LabelSelectorBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return withNewNamespaceSelectorLike(getNamespaceSelector() != null ? getNamespaceSelector(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPodSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getPodSelector() {
    return this.podSelector!=null?this.podSelector.build():null;
  }
  public io.fabric8.kubernetes.api.model.LabelSelector buildPodSelector() {
    return this.podSelector!=null?this.podSelector.build():null;
  }
  public A withPodSelector(io.fabric8.kubernetes.api.model.LabelSelector podSelector) {
    _visitables.get("podSelector").remove(this.podSelector);
    if (podSelector!=null){ this.podSelector= new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(podSelector); _visitables.get("podSelector").add(this.podSelector);} return (A) this;
  }
  public java.lang.Boolean hasPodSelector() {
    return this.podSelector != null;
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.PodSelectorNested<A> withNewPodSelector() {
    return new io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluentImpl.PodSelectorNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.PodSelectorNested<A> withNewPodSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return new io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluentImpl.PodSelectorNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.PodSelectorNested<A> editPodSelector() {
    return withNewPodSelectorLike(getPodSelector());
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.PodSelectorNested<A> editOrNewPodSelector() {
    return withNewPodSelectorLike(getPodSelector() != null ? getPodSelector(): new io.fabric8.kubernetes.api.model.LabelSelectorBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.PodSelectorNested<A> editOrNewPodSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return withNewPodSelectorLike(getPodSelector() != null ? getPodSelector(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NetworkPolicyPeerFluentImpl that = (NetworkPolicyPeerFluentImpl) o;
    if (ipBlock != null ? !ipBlock.equals(that.ipBlock) :that.ipBlock != null) return false;
    if (namespaceSelector != null ? !namespaceSelector.equals(that.namespaceSelector) :that.namespaceSelector != null) return false;
    if (podSelector != null ? !podSelector.equals(that.podSelector) :that.podSelector != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ipBlock,  namespaceSelector,  podSelector,  additionalProperties,  super.hashCode());
  }
  public class IpBlockNestedImpl<N> extends io.fabric8.kubernetes.api.model.networking.v1.IPBlockFluentImpl<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.IpBlockNested<N>> implements io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.IpBlockNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    IpBlockNestedImpl(io.fabric8.kubernetes.api.model.networking.v1.IPBlock item) {
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1.IPBlockBuilder(this, item);
    }
    IpBlockNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1.IPBlockBuilder(this);
    }
    io.fabric8.kubernetes.api.model.networking.v1.IPBlockBuilder builder;
    public N and() {
      return (N) NetworkPolicyPeerFluentImpl.this.withIpBlock(builder.build());
    }
    public N endIpBlock() {
      return and();
    }
    
  }
  public class NamespaceSelectorNestedImpl<N> extends io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.NamespaceSelectorNested<N>> implements io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.NamespaceSelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    NamespaceSelectorNestedImpl(io.fabric8.kubernetes.api.model.LabelSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this, item);
    }
    NamespaceSelectorNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LabelSelectorBuilder builder;
    public N and() {
      return (N) NetworkPolicyPeerFluentImpl.this.withNamespaceSelector(builder.build());
    }
    public N endNamespaceSelector() {
      return and();
    }
    
  }
  public class PodSelectorNestedImpl<N> extends io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.PodSelectorNested<N>> implements io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.PodSelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PodSelectorNestedImpl(io.fabric8.kubernetes.api.model.LabelSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this, item);
    }
    PodSelectorNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LabelSelectorBuilder builder;
    public N and() {
      return (N) NetworkPolicyPeerFluentImpl.this.withPodSelector(builder.build());
    }
    public N endPodSelector() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-networking-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/NetworkPolicyPeerFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class NetworkPolicyPeerFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent<A>{
  public NetworkPolicyPeerFluentImpl() {
  }
  public NetworkPolicyPeerFluentImpl(io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeer instance) {
    this.withIpBlock(instance.getIpBlock()); 
    this.withNamespaceSelector(instance.getNamespaceSelector()); 
    this.withPodSelector(instance.getPodSelector()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.networking.v1.IPBlockBuilder ipBlock;
  private io.fabric8.kubernetes.api.model.LabelSelectorBuilder namespaceSelector;
  private io.fabric8.kubernetes.api.model.LabelSelectorBuilder podSelector;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildIpBlock instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.networking.v1.IPBlock getIpBlock() {
    return this.ipBlock!=null?this.ipBlock.build():null;
  }
  public io.fabric8.kubernetes.api.model.networking.v1.IPBlock buildIpBlock() {
    return this.ipBlock!=null?this.ipBlock.build():null;
  }
  public A withIpBlock(io.fabric8.kubernetes.api.model.networking.v1.IPBlock ipBlock) {
    _visitables.get("ipBlock").remove(this.ipBlock);
    if (ipBlock!=null){ this.ipBlock= new io.fabric8.kubernetes.api.model.networking.v1.IPBlockBuilder(ipBlock); _visitables.get("ipBlock").add(this.ipBlock);} return (A) this;
  }
  public java.lang.Boolean hasIpBlock() {
    return this.ipBlock != null;
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.IpBlockNested<A> withNewIpBlock() {
    return new io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluentImpl.IpBlockNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.IpBlockNested<A> withNewIpBlockLike(io.fabric8.kubernetes.api.model.networking.v1.IPBlock item) {
    return new io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluentImpl.IpBlockNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.IpBlockNested<A> editIpBlock() {
    return withNewIpBlockLike(getIpBlock());
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.IpBlockNested<A> editOrNewIpBlock() {
    return withNewIpBlockLike(getIpBlock() != null ? getIpBlock(): new io.fabric8.kubernetes.api.model.networking.v1.IPBlockBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.IpBlockNested<A> editOrNewIpBlockLike(io.fabric8.kubernetes.api.model.networking.v1.IPBlock item) {
    return withNewIpBlockLike(getIpBlock() != null ? getIpBlock(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildNamespaceSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getNamespaceSelector() {
    return this.namespaceSelector!=null?this.namespaceSelector.build():null;
  }
  public io.fabric8.kubernetes.api.model.LabelSelector buildNamespaceSelector() {
    return this.namespaceSelector!=null?this.namespaceSelector.build():null;
  }
  public A withNamespaceSelector(io.fabric8.kubernetes.api.model.LabelSelector namespaceSelector) {
    _visitables.get("namespaceSelector").remove(this.namespaceSelector);
    if (namespaceSelector!=null){ this.namespaceSelector= new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(namespaceSelector); _visitables.get("namespaceSelector").add(this.namespaceSelector);} return (A) this;
  }
  public java.lang.Boolean hasNamespaceSelector() {
    return this.namespaceSelector != null;
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.NamespaceSelectorNested<A> withNewNamespaceSelector() {
    return new io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluentImpl.NamespaceSelectorNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return new io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluentImpl.NamespaceSelectorNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.NamespaceSelectorNested<A> editNamespaceSelector() {
    return withNewNamespaceSelectorLike(getNamespaceSelector());
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector() {
    return withNewNamespaceSelectorLike(getNamespaceSelector() != null ? getNamespaceSelector(): new io.fabric8.kubernetes.api.model.LabelSelectorBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return withNewNamespaceSelectorLike(getNamespaceSelector() != null ? getNamespaceSelector(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPodSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getPodSelector() {
    return this.podSelector!=null?this.podSelector.build():null;
  }
  public io.fabric8.kubernetes.api.model.LabelSelector buildPodSelector() {
    return this.podSelector!=null?this.podSelector.build():null;
  }
  public A withPodSelector(io.fabric8.kubernetes.api.model.LabelSelector podSelector) {
    _visitables.get("podSelector").remove(this.podSelector);
    if (podSelector!=null){ this.podSelector= new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(podSelector); _visitables.get("podSelector").add(this.podSelector);} return (A) this;
  }
  public java.lang.Boolean hasPodSelector() {
    return this.podSelector != null;
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.PodSelectorNested<A> withNewPodSelector() {
    return new io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluentImpl.PodSelectorNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.PodSelectorNested<A> withNewPodSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return new io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluentImpl.PodSelectorNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.PodSelectorNested<A> editPodSelector() {
    return withNewPodSelectorLike(getPodSelector());
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.PodSelectorNested<A> editOrNewPodSelector() {
    return withNewPodSelectorLike(getPodSelector() != null ? getPodSelector(): new io.fabric8.kubernetes.api.model.LabelSelectorBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.PodSelectorNested<A> editOrNewPodSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return withNewPodSelectorLike(getPodSelector() != null ? getPodSelector(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NetworkPolicyPeerFluentImpl that = (NetworkPolicyPeerFluentImpl) o;
    if (ipBlock != null ? !ipBlock.equals(that.ipBlock) :that.ipBlock != null) return false;
    if (namespaceSelector != null ? !namespaceSelector.equals(that.namespaceSelector) :that.namespaceSelector != null) return false;
    if (podSelector != null ? !podSelector.equals(that.podSelector) :that.podSelector != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ipBlock,  namespaceSelector,  podSelector,  additionalProperties,  super.hashCode());
  }
  public class IpBlockNestedImpl<N> extends io.fabric8.kubernetes.api.model.networking.v1.IPBlockFluentImpl<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.IpBlockNested<N>> implements io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.IpBlockNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    IpBlockNestedImpl(io.fabric8.kubernetes.api.model.networking.v1.IPBlock item) {
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1.IPBlockBuilder(this, item);
    }
    IpBlockNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.networking.v1.IPBlockBuilder(this);
    }
    io.fabric8.kubernetes.api.model.networking.v1.IPBlockBuilder builder;
    public N and() {
      return (N) NetworkPolicyPeerFluentImpl.this.withIpBlock(builder.build());
    }
    public N endIpBlock() {
      return and();
    }
    
  }
  public class NamespaceSelectorNestedImpl<N> extends io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.NamespaceSelectorNested<N>> implements io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.NamespaceSelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    NamespaceSelectorNestedImpl(io.fabric8.kubernetes.api.model.LabelSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this, item);
    }
    NamespaceSelectorNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LabelSelectorBuilder builder;
    public N and() {
      return (N) NetworkPolicyPeerFluentImpl.this.withNamespaceSelector(builder.build());
    }
    public N endNamespaceSelector() {
      return and();
    }
    
  }
  public class PodSelectorNestedImpl<N> extends io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.PodSelectorNested<N>> implements io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyPeerFluent.PodSelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PodSelectorNestedImpl(io.fabric8.kubernetes.api.model.LabelSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this, item);
    }
    PodSelectorNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LabelSelectorBuilder builder;
    public N and() {
      return (N) NetworkPolicyPeerFluentImpl.this.withPodSelector(builder.build());
    }
    public N endPodSelector() {
      return and();
    }
    
  }
  
}
